/**
 * Calls a callback function when all the images from a collection have been loaded.
 * A "callback" parameter should be added - the function to be called when all the images are loaded.
 * Dependencies: jQuery (http://jquery.com/)
 * 
 * Example usage: $('.test img').onPexetoImagesLoaded({callback:showImages});
 * 
 * @author Pexeto
 */
(function($){
	$.fn.onPexetoImagesLoaded = function (options) {
		var defaults = {},
			o = $.extend(defaults, options), 
			$images = $(this), 
			ie = $.browser.msie;
		
		

		/**
		 * Contains the main plugin functionality - once all the images are loaded, calls the callback function.
		 */
		function init() {
			var imagesNum = $images.length, imgLoaded = 0;

			$images.each(function() {
				
				$(this).load(function(e) {
					e.stopPropagation();
					imgLoaded++;
					if (imgLoaded === imagesNum) {
						o.callback.call(this);
					}
				});

				if (this.complete || (ie && this.width)) {
					$(this).trigger('load');
				}
			});
		}
		
		init();
	};
}(jQuery));

/**
 * This is a slider with small thumbnail previews. When the smaller thumbnail is clicked,
 * a bigger preview image fades in. Also there is a pagination included for the thumbnails
 * so that when there are more of them included, they are separated by pages and users can
 * navigate through them using navigation arrows.
 * 
 * @author Pexeto
 * http://pexeto.com
 */

(function($){
	$.fn.pexetoSlideshow=function(options){
		var defaults={
			interval:4000,   //the interval between changing the images when autoplay is turned on (in miliseconds)
			autoplay:true,   //if set to false, images won't be changed automatically, only users will be able to do it
			imgPerScroll:9,  //the number of small thumbnail images per scroll (page)
			thumbContainerId:'slider-navigation',  //the ID of the div that will contain the small thumbnails
			scrollSpeed:700,  //the speed of the thumbnail scroll (in miliseconds)
			pauseInterval:5000,  //the pause interval (in miliseconds)- when an user clicks on an image or arrow, the autoplay pauses for this interval of time
			pauseOnHover:true,
			hideContent:true,
			hideText:"Hide Menu",
			showText:"Show Menu",
			closedClass:"closed"
		};
		
		options=$.extend(defaults, options);
		var api, 
			timer=-1, 
			images=[], 
			current, 
			root, 
			thumbContainer, 
			containerNum=0, 
			inAnimation=false, 
			windowFocus=true, 
			hideButton=null, 
			navHidden=false, 
			navInAnimation=false,
			headerHeight=$('#header').outerHeight() || 200;
		
		
		
		root=$(this);
		thumbContainer=$('#'+options.thumbContainerId);
		current=root.find('img:first');
		
		
		/**
		 * Inits the slider.
		 */
		function init(){
				
			if(root.find('img').length>0){
				thumbContainer.css({visibility:'visible'});
				
				root.find('.loading').hide();
				
				getImages();
				printScrollable();
				
				$('.right').click(function(){
					api.next(500);
				});
				
				//set the timer
				$(window).one("load",function(){
					if(options.autoplay){
						setTimer();
					}
					if(options.hideContent){
						hideNavigation();
					}
				});
				
				if(options.autoplay){
					setWindowEvents();
				}
				
				if(options.hideContent){
					setHidingFunctionality();
				}
			}
		}
		
		function setHidingFunctionality(){
			hideButton=$('<div id="hide-button"><span>'+options.hideText+'</span></div>');
			$('#header').append(hideButton);
			
			hideButton.click(function(){
				if(!navInAnimation){
					if(navHidden){
						showNavigation();
					}else{
						hideNavigation();
					}
				}
			});
		}
		
		function showNavigation(){
			navInAnimation=true;
			hideButton.removeClass(options.closedClass).find("span").text(options.hideText);
			
			$('#footer').animate({height:"show", opacity:1}, 500);
			$('#slider-navigation-container').animate({bottom:46}, 500);
			$('#header').animate({marginTop:0}, 500, function(){
				navInAnimation=false;
				navHidden=false;
			});
		}
		
		function hideNavigation(){
			navInAnimation=true;
			hideButton.addClass(options.closedClass).find("span").text(options.showText);
			
			$('#footer').animate({height:"hide", opacity:0}, 500);
			$('#slider-navigation-container').animate({bottom:0}, 500);
			$('#header').animate({marginTop:-headerHeight}, 500, function(){
				navInAnimation=false;
				navHidden=true;
			});
		}
		
		/**
		 * Inserts the bigger images into an array for further use.
		 */
		function getImages(){
			root.find('img').each(function(i){
				var img=$(this).data('index', i);
				images[i]={img:img};
				
				(function(i){
					img.onPexetoImagesLoaded({callback:function(){
						$(this).hide().css({visibility:"visible"});
						images[i].imgLoaded=true;
						if(images[i].thumbLoaded){
							showThumbnail(i);
						}
					}
					});
				})(i);
				
			});
			
		}
		
		function showThumbnail(i){
			if(images[i].imgLoaded && images[i].thumbLoaded){
				images[i].thumb.animate({opacity:1}, 800).parent().css({backgroundImage:'none'});
				if(i===0){
					images[i].img.toggleClass('current').fadeIn(1100);
					root.removeClass("loading");
				}
			}
		}
		
		/**
		 * Prints the thumbnail container.
		 */
		function printScrollable(){	
			thumbContainer.find('img:first').addClass('active');
			
			//display navigation arrows if there are more than one scrollable page
			containerNum=thumbContainer.find('div.items div').not(".thumbnail-wrapper").length;
			if(containerNum>1){
				$('<a class="prev browse" id="left-arrow"></a><a class="next browse" id="right-arrow"></a>').insertBefore(thumbContainer);
			}
			
			//enable the scrollable plugin
			var scrollable=pexetoSite.setScrollable();
			api = scrollable.data("scrollable");	
			
			setClickHandlers();
		}
		
		/**
		 * Set click event event handlers for the thumbnail images and navigation arrows.
		 */
		function setClickHandlers(){
			thumbContainer.find('img').each(function(i){
				var img=$(this);
				images[i].thumb=$(this);
				
				img.click(function(){
					if(current.data('index')!==i && !inAnimation && images[i].imgLoaded && images[i].thumbLoaded){
						showCurrent(images[i].img);
						$(".items img").removeClass("active");
						img.addClass("active");
						
						pause();
					}
				}).hover(function(){
					$(this).css({cursor:'pointer'});
				});
				
				(function(i){
					img.onPexetoImagesLoaded({callback:function(){
							images[i].thumbLoaded=true;
							if(images[i].imgLoaded){
								showThumbnail(i);
							}
						}
					});
				})(i);
			});
			
			//pause the autoplay on arrow click
			thumbContainer.siblings('.browse').click(function(){
				pause();
			}).mouseover(function(){
				$(this).css({cursor:'pointer'});
			});
			
			$('#left-arrow').mousedown(function(){
				$(this).animate({marginLeft:-3}, 100);
			}).mouseup(function(){
				$(this).animate({marginLeft:0}, 100);
			});
			
			$('#right-arrow').mousedown(function(){
				$(this).animate({marginRight:-3}, 100);
			}).mouseup(function(){
				$(this).animate({marginRight:0}, 100);
			});
		}
		
		function setWindowEvents(){
			$(window).focus(function(){
				windowFocus=true;
				if(timer===-1){
					setTimer();
				}
			});

			$(window).blur(function(){
				windowFocus=false;
				if(timer!==-1){
					stopSlider();
				}
			});
		}
		
		/**
		 * Pauses the autoplay.
		 */
		function pause(){
			stopSlider();
			setTimeout(function(){setTimer();}, options.pauseInterval);
		}
		
		/**
		 * Stops the autoplay.
		 */
		function stopSlider(){
			window.clearInterval(timer);
			timer=-1;
		}
		
		/**
		 * Shows the image that has been selected.
		 * @param the image object to display
		 */
		function showCurrent(img){
			inAnimation=true;
			img.toggleClass('current').fadeIn(600,function(){
				var title=img.attr('title');
				inAnimation=false;
			});
			
			current.fadeOut(function(){
				current.removeClass('current');	
			});
			current=img;
		}
		
		/**
		 * Sets the timer for autoplay.
		 */
		function setTimer(){
			if(options.autoplay && timer===-1 && windowFocus){
				timer = window.setInterval(function(){showNext();}, options.interval);
			}
		}
		
		/**
		 * Shows the next image, used when autoplay is enabled.
		 */
		function showNext(){
			var nextIndex=current.data('index')===(images.length-1)?0:Number(current.data('index'))+1,
				next=images[nextIndex].img,
				nextContPosition=parseInt(nextIndex/options.imgPerScroll,10),
				apiIndex=api.getIndex();
			if(nextContPosition!==apiIndex){
				api.seekTo(nextContPosition, options.scrollSpeed);
			}
			
			$(".items img").removeClass('active').eq(nextIndex).addClass('active');
			
			showCurrent(next);
			
		}
		

		if(root.length>0){
			init();
		}
		
	};
}(jQuery));